@@ -1,10 +1,10 @@
 
 
-VERSION = (0, 8, 0)
+VERSION = (0, 9, 1)
 """Application version number tuple."""
 
 VERSION_STR = '.'.join(map(str, VERSION))
 """Application version number string."""
 
 
-default_app_config = 'siteforms.config.SiteformsConfig'
\ No newline at end of file
+default_app_config = 'siteforms.apps.SiteformsConfig'
\ No newline at end of file
