@@ -354,8 +354,16 @@ class SiteformsMixin(BaseForm):
         """
         return self.Composer(self)
 
-    def render(self) -> str:
+    def render(self, template_name=None, context=None, renderer=None):
         """Renders this form as a string."""
+
+        if template_name:
+            # Use Django 4.0+ default implementation to avoid recursion.
+            return mark_safe((renderer or self.renderer).render(
+                template_name or self.template_name,
+                context or self.get_context(),
+            ))
+
         def render_():
             return mark_safe(self.get_composer().render(
                 render_form_tag=self.composer_render_form_tag,
@@ -387,6 +395,9 @@ class SiteformsMixin(BaseForm):
 
         return is_multipart
 
+    def _get_widget_readonly_cls(self, field_name: str) -> Type[ReadOnlyWidget]:
+        return getattr(self.Meta, 'widgets_readonly', {}).get(field_name, ReadOnlyWidget)
+
     def _clean_fields(self):
         # this ensures valid attributes on validation including that in formsets
         self._apply_attrs(callback=super()._clean_fields)
@@ -396,6 +407,7 @@ class SiteformsMixin(BaseForm):
         disabled = self.disabled_fields
         hidden = self.hidden_fields
         readonly = self.readonly_fields
+        get_readonly_cls = self._get_widget_readonly_cls
 
         all_macro = '__all__'
 
@@ -420,7 +432,7 @@ class SiteformsMixin(BaseForm):
                         and not isinstance(base_field, SubformField)
                     )
                     if make_read_only:
-                        widget = ReadOnlyWidget(
+                        widget = get_readonly_cls(field_name)(
                             bound_field=field,
                             original_widget=original_widget,
                         )
